pub struct ClassTransition {
pub class_id: Uuid,
pub cost: Vec<CurrencyUnit>,
}Fields
class_id: Uuidcost: Vec<CurrencyUnit>Trait Implementations
Sourceimpl Clone for ClassTransition
impl Clone for ClassTransition
Sourcefn clone(&self) -> ClassTransition
fn clone(&self) -> ClassTransition
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ClassTransition
impl CustomType for ClassTransition
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ClassTransition
impl Debug for ClassTransition
Sourceimpl Default for ClassTransition
impl Default for ClassTransition
Sourcefn default() -> ClassTransition
fn default() -> ClassTransition
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClassTransition
impl<'de> Deserialize<'de> for ClassTransition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClassTransition
impl JsonSchema for ClassTransition
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ClassTransition
impl PartialEq for ClassTransition
Sourceimpl Serialize for ClassTransition
impl Serialize for ClassTransition
Sourceimpl Tsify for ClassTransition
impl Tsify for ClassTransition
const DECL: &'static str = "export interface ClassTransition {\n class_id: Uuid;\n cost: CurrencyUnit[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ClassTransition
impl StructuralPartialEq for ClassTransition